package ij.measure;

/** This is a table for storing measurement results as columns of real numbers. */
public class ResultsTable {

	public static final int MAX_COLUMNS = 100;
	
	private int counter;
	private int nColumns;
	private float[][] column = new float[MAX_COLUMNS][];
	private String[] name = new String[MAX_COLUMNS];
	private int maxRows = 100;

	/** Constructs an empty ResultsTable with the counter=0 and no columns. */
	public ResultsTable() {
	}
	
	/** Adds a new column to the table and returns its index. */
	public int addColumn(String name) {
		if (nColumns>=MAX_COLUMNS)
			return -1;
		nColumns++;
		column[nColumns-1] = new float[maxRows];
		this.name[nColumns-1] = name;
		return nColumns - 1;
	}
	
	/** Increments the measurement counter by one. */
	public void incrementCounter() {
		counter++;
		if (counter==maxRows) {
			for (int i=0; i<nColumns; i++) {
				float[] tmp1 = new float[maxRows*2];
				System.arraycopy(column[i], 0, tmp1, 0, maxRows);
				column[i] = tmp1;
			}
			String[] tmp2 = new String[maxRows*2];
			System.arraycopy(name, 0, tmp2, 0, maxRows);
			name = tmp2;
			maxRows *= 2;
		}
	}
	
	/** Returns the current value of the measurement counter. */
	public int getCounter() {
		return counter;
	}
	
	/** Sets the last value in the specified column. */
	public void addValue(int columnIndex, double value) {
		if ((columnIndex<0) || (columnIndex>=nColumns))
			throw new IllegalArgumentException("Index out of range: "+columnIndex);
		column[columnIndex][counter-1] = (float)value;
	}
	
	/** Returns a copy of the specified column as a float array. */
	public float[] getColumn(int columnIndex) {
		if ((columnIndex<0) || (columnIndex>=nColumns))
			throw new IllegalArgumentException("Index out of range: "+columnIndex);
		float[] data = new float[counter];
		for (int i=0; i<counter; i++)
			data[i] = column[columnIndex][i];
		return data;
	}
}
