package ij.plugin.filter;
import ij.*;
import ij.gui.*;
import ij.process.*;
import java.awt.*;

/** Implements the Analyze/Set Scale command. */
public class Scale implements PlugInFilter {
    private ImagePlus imp;

	public int setup(String arg, ImagePlus imp) {
		this.imp = imp;
		return DOES_ALL+NO_CHANGES;
	}

	public void run(ImageProcessor ip) {
		double measured = 0.0;
		double known = 1.0;
		double aspectRatio = 1.0;
		String unit = "cm";
		
		if (imp.sCalibrated && imp.pixelWidth>0.0) {
			measured = 1.0/imp.pixelWidth;
			known = 1.0;
			aspectRatio = imp.pixelHeight/imp.pixelWidth;
			unit = imp.unit;
		}
		Roi roi = imp.getRoi();
		if (roi!=null && (roi instanceof Line)) {
			boolean wasCalibrated = imp.sCalibrated;
			imp.sCalibrated = false;
			measured = roi.getLength();
			imp.sCalibrated = wasCalibrated;
			known = 0.0;
		}
		
		GenericDialog gd = new GenericDialog("Set Scale", IJ.getInstance());
		gd.addNumericField("Distance in Pixels:", measured, 2);
		gd.addNumericField("Known Distance:", known, 2);
		gd.addNumericField("Pixel Aspect Ratio:", aspectRatio, 1);
		gd.addStringField("Unit of Measurement:", unit);
		gd.showDialog();
		if (gd.wasCanceled())
			return;
		measured = gd.getNextNumber();
		known = gd.getNextNumber();
		aspectRatio = gd.getNextNumber();
		unit = gd.getNextString();
		if (measured<=0.0 || known<=0.0 || unit.startsWith("pixel") || unit.startsWith("Pixel") || unit.equals("")) {
			imp.sCalibrated = false;
			imp.unit = "pixel";
			imp.units = "pixels";
			imp.pixelWidth = 1.0;
			imp.pixelHeight = 1.0;
		} else {
			imp.pixelWidth = known/measured;
			if (aspectRatio!=0.0)
				imp.pixelHeight = imp.pixelWidth*aspectRatio;
			else
				imp.pixelHeight = imp.pixelWidth;
			imp.unit = unit;
			if (unit.equals("inch"))
				imp.units = "inches";
			else
				imp.units = unit;
			imp.sCalibrated = true;
		}
			imp.getWindow().repaint();
	}

}